@@ -7,7 +7,7 @@ use FFI::C::FFI ();
 use Ref::Util qw( is_ref is_plain_arrayref );
 
 # ABSTRACT: Structured data instance for FFI
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 sub AUTOLOAD
@@ -87,6 +87,14 @@ sub AUTOLOAD
   }
 }
 
+sub can
+{
+  my($self, $name) = @_;
+  $self->{def}->{members}->{$name}
+    ? sub { shift->$name(@_) }
+    : $self->SUPER::can($name);
+}
+
 sub DESTROY
 {
   my($self) = @_;
@@ -149,7 +157,7 @@ FFI::C::Struct - Structured data instance for FFI
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
